
import re

from datetime import datetime

from django.conf import settings


def clean_code(text):
    return re.sub(r'[\W_]+', '', text).lower()


def get_date_from_request(request, key):
    return request.GET.get(
        key,
        datetime.now().date().strftime(settings.DATE_INPUT_FORMATS[0])
    )




from django.contrib import admin
from django.shortcuts import render as django_render


def render(request, template_name, context=None):

    ctx = admin.site.each_context(request)
    ctx.update(context or {})

    return django_render(request, template_name, ctx)
